@@ -23,14 +23,6 @@ from csv import QUOTE_NONE
 #
 _KNOWN_TYPES = ['c', 'd', 'x', 'f', 'e', 't']
 _IMPLEMENTED_TYPES = ['d', 'f', 'e', 't']
-_KNOWN_KEYS = ["cset", "prgm", "artp", "axes", "idnt",
-               "t1", "t2", "dt", "dtbnummax", "index",
-               "groups", "xmin", "ymin", "delta", "refx",
-               "refy", "ggcs", "zscl", "sscl", "sk",
-               "uref", "dref", "mode", "avmean",
-               "name", "unit", "vldf", "valid", "locl",
-               "form", "refv", "exceed", "sequ", "file",
-               "dims", "size", "lowb", "hghb"]
 _COMPRESSION_LEVEL = 6
 # binary format strings:
 # assemple binary format
@@ -350,6 +342,11 @@ class DataFile(object):
         self.data = values
 
     def _write_file(self, filename=None):
+        """
+        write file
+
+        :param filename: defaults to None
+        """
         #
         #  write file
         #
@@ -406,20 +403,19 @@ class DataFile(object):
         #
         # loop over known keys but write only keys defined in object
         lines = []
-        for key in _KNOWN_KEYS:
-            if key in self.header.keys():
-                value = self._attrib(key)
-                # is value a scalar?
-                if not isinstance(value, list):
-                    value = [value]
-                # numbers without quotes
-                if all([np.issubdtype(type(x), np.number) for x in value]):
-                    value = '  '.join([str(x) for x in value])
-                else:
-                    # characters surrounded by quotes
-                    value = '  '.join(['"%s"' % x for x in value])
-                lines.append('  '.join((key, value)))
-                logging.debug('header: %s' % lines[-1])
+        for key in self.header.keys():
+            value = self._attrib(key)
+            # is value a scalar?
+            if not isinstance(value, list):
+                value = [value]
+            # numbers without quotes
+            if all([np.issubdtype(type(x), np.number) for x in value]):
+                value = '  '.join([str(x) for x in value])
+            else:
+                # characters surrounded by quotes
+                value = '  '.join(['"%s"' % x for x in value])
+            lines.append('  '.join((key, value)))
+            logging.debug('header: %s' % lines[-1])
         con1.writelines([x + '\r\n' for x in lines])
         con1.writelines(['*' + '\r\n'])
         #
@@ -736,9 +732,9 @@ class DataFile(object):
 
     # ----------------------------------------------------------------------
     def _set_axes(self, axes):
-        #
-        # set grid-defining header values from axes or grid tuple
-        #
+        """
+        set grid-defining header values from axes or grid tuple
+        """
         if not isinstance(axes, pd.DataFrame):
             raise ValueError('axes must be pandas.DataFrame')
         if 'x' not in axes.keys:
@@ -896,17 +892,16 @@ class DataFile(object):
         return (data_file, gz)
 
     def _parse_sequ(self, dims, sequ, lowb, hghb):
-        #
-        # get index oder and orientation
-        #
-        # index sequence gives order (slowest counting to fastest counting)
-        # of numbers in file e.g. "k+,j-,i+"
-        # index position is position of axis in list seq
-        # e.g. x-axis boundaries are in first column in lowb/highb
-        #      x-index "i" is found in last position, direction is +
-        #             -> fastest counting, increasing
-        #             -> along data rows, lowes x left highest x right
-        #
+        """
+        get index oder and orientation
+        index sequence gives order (slowest counting to fastest counting)
+        of numbers in file e.g. "k+,j-,i+"
+        index position is position of axis in list seq
+        e.g. x-axis boundaries are in first column in lowb/highb
+             x-index "i" is found in last position, direction is +
+                    -> fastest counting, increasing
+                    -> along data rows, lowes x left highest x right
+        """
         logging.debug('sequ: {}'.format(sequ))
         sequ = sequ.split(',')
         if len(sequ) != dims:
@@ -1153,6 +1148,15 @@ class DataFile(object):
     # calculate x/y/z axes values in model coordinates
     #
     def axes(self, ax=None):
+        """
+        Return positions of grid lines in model coordinates
+
+        :param ax: (string, optional) name of axis to return. \
+                   If missing or `None`, all axes are returned.
+
+        :return: `dict` with axis names as keys, containing\
+                 list(s) of positions as values.
+        """
         self._get_axes(ax)
 
     # ----------------------------------------------------------------------
@@ -1203,5 +1207,11 @@ class DataFile(object):
         return out
 
     def write(self, filename):
+        '''
+        Writes DataFile object to file
+
+        :param filename: (string) name of file to write, optionally
+                         containing a path.
+        '''
         self._write_file(filename)
 
